﻿namespace ElmahR
{
    #region Imports

    using System;
    using System.Web;
    using System.Web.Routing;
    using System.Web.Optimization;
    using Core;
    using Core.Persistors;
    using Core.Services;
    using Core.Config;
    using SignalR;
    using Ninject;
    using SignalR.Ninject;

    #endregion

    public class Global : HttpApplication
    {
        protected void Application_Start(object sender, EventArgs e)
        {
            var context = HttpContext.Current;
            var section = context.GetSection("elmahr") as RootSection;

            var kernel = new StandardKernel();
            GlobalHost.DependencyResolver = new NinjectDependencyResolver(kernel);

            kernel.Bind<IApplications>()
                  .To<Applications>()
                  .InSingletonScope();

            var persistor = section != null ? section.PersistorType : null;
            if (string.IsNullOrWhiteSpace(persistor))
                kernel.Bind<IApplicationsPersistor>()
                      .To<EntityFrameworkPersistor>()
                      .InSingletonScope();
            else
            {
                var t = Type.GetType(persistor);
                if (t != null)
                    kernel.Bind<IApplicationsPersistor>()
                          .To(t)
                          .InSingletonScope();
            }

            kernel.Bind<IUserService>()
                  .To<UserService>()
                  .InSingletonScope();

            RouteTable.Routes.MapConnection<StartupConnection>("commands", "commands/{*operation}");

            RouteTable.Routes.MapHubs("~/signalr05");

            var bundles = BundleTable.Bundles;
            var version = Core.Extensions.Version.Current;

            bundles.Add(new ScriptBundle("~/Scripts/" + version + "/jsbase").Include(
                "~/Scripts/jquery-1.8.2.js",
                "~/Scripts/jquery-ui-1.8.24.js",
                "~/Scripts/json2.js",
                "~/Scripts/jquery.signalR-0.5.3.js",
                "~/Scripts/jquery.timeago.js",
                "~/Scripts/knockout-2.1.0.js",
                "~/Scripts/underscore.js",
                "~/Scripts/raphael.js"
                ));

            bundles.Add(new ScriptBundle("~/Scripts/" + version + "/jscore").Include(
                "~/Scripts/ElmahR/elmahr.core.js"
                ));

            bundles.Add(new ScriptBundle("~/Scripts/" + version + "/jsmore").Include(
                "~/Scripts/ElmahR/elmahr.stats.js",
                "~/Scripts/ElmahR/elmahr.init.js",
                "~/Content/Themes/elmahr/bootstrap/js/bootstrap-collapse.js"
                ));

            bundles.Add(new StyleBundle("~/Content/Themes/base/css").Include(
                "~/Content/Themes/base/jquery-ui.css"
                ));

            bundles.Add(new StyleBundle("~/Content/Themes/elmahr/bootstrap/" + version + "/css").Include(
                "~/Content/Themes/elmahr/bootstrap/css/bootstrap.css",
                "~/Content/Themes/elmahr/bootstrap/css/bootstrap-responsive.css",
                "~/Content/Themes/elmahr/bootstrap/css/bootstrap-applied.css",
                "~/Content/Themes/elmahr/bootstrap/css/elmahr.css"
                ));

        }
    }
}